@@ -2,14 +2,18 @@ package Dist::Zilla::PluginBundle::Author::CHIM;
 
 # ABSTRACT: Dist::Zilla configuration the way CHIM does it
 our $AUTHORITY = 'cpan:CHIM'; # AUTHORITY
-our $VERSION = '0.051002'; # VERSION
+our $VERSION = '0.051003'; # VERSION
 
 use strict;
 use warnings;
 use Moose;
 
 use Dist::Zilla;
-with 'Dist::Zilla::Role::PluginBundle::Easy';
+
+with qw(
+    Dist::Zilla::Role::PluginBundle::Easy
+    Dist::Zilla::Role::PluginBundle::PluginRemover
+);
 
 has dist => (
     is       => 'ro',
@@ -18,41 +22,6 @@ has dist => (
     default  => sub { $_[0]->payload->{dist} },
 );
 
-has authority => (
-    is       => 'ro',
-    isa      => 'Str',
-    lazy     => 1,
-    default  => sub { $_[0]->payload->{authority} || 'cpan:CHIM' },
-);
-
-has github_username => (
-    is       => 'ro',
-    isa      => 'Str',
-    lazy     => 1,
-    default  => sub { $_[0]->payload->{github_username} || 'Wu-Wu' },
-);
-
-has github_reponame => (
-    is       => 'ro',
-    isa      => 'Str',
-    lazy     => 1,
-    default  => sub { $_[0]->payload->{github_reponame} || $_[0]->dist },
-);
-
-has github_repopath => (
-    is       => 'ro',
-    isa      => 'Str',
-    lazy     => 1,
-    default  => sub { join '/' => 'github.com', $_[0]->github_username, $_[0]->github_reponame },
-);
-
-has fake_release => (
-    is       => 'ro',
-    isa      => 'Bool',
-    lazy     => 1,
-    default  => sub { $_[0]->payload->{fake_release} || 0 },
-);
-
 
 sub mvp_multivalue_args {
     return qw(
@@ -62,6 +31,7 @@ sub mvp_multivalue_args {
         MetaNoIndex.file
         GatherDir.exclude_match
         GitCheck.allow_dirty
+        GithubMeta.remote
     );
 }
 
@@ -94,6 +64,20 @@ sub configure {
         ),
     };
 
+    my $github_meta__options = {
+        'homepage'  => $self->payload->{'GithubMeta.homepage'} ||
+                            'https://metacpan.org/release/' . $self->dist,
+        'remote'    => $self->payload->{'GithubMeta.remote'} ||
+                            [qw( origin github gh )],
+        'issues'    => $self->payload->{'GithubMeta.issues'} || 1,
+        ( $self->payload->{'user'} ?
+            ( 'user' => $self->payload->{'github.user'} ) : ( )
+        ),
+        ( $self->payload->{'repo'} ?
+            ( 'repo' => $self->payload->{'github.repo'} ) : ( )
+        ),
+    };
+
     $self->add_plugins(
         # version provider
         [ 'Git::NextVersion' => {
@@ -116,7 +100,7 @@ sub configure {
             }
         ],
         [ 'Authority' => {
-                'authority'      => $self->authority,
+                'authority'      => $self->payload->{'authority'} || 'cpan:CHIM',
                 'do_metadata'    => 1,
                 'locate_comment' => 1,
             }
@@ -136,23 +120,15 @@ sub configure {
 
         [ 'TravisCI::StatusBadge' => {
                 ':version'  => '0.004',
-                'user'      => $self->github_username,
-                'repo'      => $self->github_reponame,
+                'user'      => $self->payload->{'github.user'} || 'Wu-Wu',
+                'repo'      => $self->payload->{'github.repo'} || $self->dist,
                 'vector'    => 1,
             },
         ],
 
         [ 'MetaNoIndex' => $meta_no_index__options ],
 
-        # set META resources
-        [ 'MetaResources' => {
-                'homepage'        => 'https://metacpan.org/release/' . $self->dist,
-                'repository.url'  => 'https://' . $self->github_repopath . '.git',
-                'repository.web'  => 'https://' . $self->github_repopath,
-                'bugtracker.web'  => 'https://' . $self->github_repopath . '/issues',
-                'repository.type' => 'git',
-            },
-        ],
+        [ 'GithubMeta' => $github_meta__options ],
 
         # add 'provides' to META
         [ 'MetaProvides::Package' => { 'meta_noindex' => 1 } ],
@@ -188,7 +164,7 @@ sub configure {
 
         # release
         [ 'ConfirmRelease' => {} ],
-        [ ($self->fake_release ? 'FakeRelease' : 'UploadToCPAN') => {} ],
+        [ ( $ENV{FAKE} || $self->payload->{'fake_release'} ? 'FakeRelease' : 'UploadToCPAN' ) => {} ],
 
         [ 'Git::Commit' => {
                 'commit_msg' => $self->payload->{'GitCommit.commit_msg'} ||
@@ -223,7 +199,7 @@ Dist::Zilla::PluginBundle::Author::CHIM - Dist::Zilla configuration the way CHIM
 
 =head1 VERSION
 
-version 0.051002
+version 0.051003
 
 =head1 DESCRIPTION
 
@@ -257,8 +233,8 @@ following dist.ini:
     location = root
 
     [TravisCI::StatusBadge]
-    user = %{github_username}
-    repo = %{github_reponame}
+    user = %{github.user}
+    repo = %{github.repo} || %{dist}
     vector = 1
 
     [MetaNoIndex]
@@ -270,13 +246,12 @@ following dist.ini:
     package   = DB
     namespace = t::lib
 
-    ;; set META resources
-    [MetaResources]
-    homepage        = https://metacpan.org/release/%{dist}
-    repository.url  = https://%{github_repopath}.git
-    repository.web  = https://%{github_repopath}
-    bugtracker.web  = https://%{github_repopath}/issues
-    repository.type = git
+    [GithubMeta]
+    homepage = https://metacpan.org/release/%{dist}
+    remote = origin
+    remote = github
+    remote = gh
+    issues = 1
 
     ;; add 'provides' to META
     [MetaProvides::Package]
@@ -328,11 +303,18 @@ following dist.ini:
     [@Author::CHIM]
     dist            = My-Very-Cool-Module
     authority       = cpan:CHIM
-    github_username = Wu-Wu
-    github_reponame = perl5-My-Very-Cool-Module
+    github.user     = Wu-Wu
 
 =head1 OPTIONS
 
+=head2 -remove
+
+Removes a plugin. Might be used multiple times.
+
+    [@Author::CHIM]
+    -remove = PodCoverageTests
+    -remove = Test::Kwalitee
+
 =head2 dist
 
 The name of the distribution. Required.
@@ -340,19 +322,17 @@ The name of the distribution. Required.
 =head2 authority
 
 This one is used to set name the CPAN author of the distibution. It should be something like C<cpan:PAUSEID>.
-Default value is I<cpan:CHIM>.
+Default value is C<cpan:CHIM>.
 
-=head2 github_username
+=head2 github.user
 
-Indicates github.com's account name. Default value is I<Wu-Wu>.
+Indicates github.com's account name. Default value is C<Wu-Wu>. Used by L<Dist::Zilla::Plugin::GithubMeta>
+and L<Dist::Zilla::Plugin::TravisCI::StatusBadge>.
 
-=head2 github_reponame
+=head2 github.repo
 
-Indicates github.com's repository name. Default value is set to value of the I<dist>-attribute name.
-
-=head2 fake_release
-
-Replaces UploadToCPAN with FakeRelease so release won't actually uploaded. Default value is I<0>.
+Indicates github.com's repository name. Default value is set to value of the L</dist> option.
+Used by L<Dist::Zilla::Plugin::GithubMeta> and L<Dist::Zilla::Plugin::TravisCI::StatusBadge>.
 
 =head2 NextRelease.time_zone
 
@@ -451,12 +431,49 @@ The commit message to use in commit after release. Default value is C<die>.
 
 See more at L<Dist::Zilla::Plugin::Git::Check>.
 
+=head2 GithubMeta.homepage
+
+Homepage of the distribution. Default value is C<https://metacpan.org/release/%{dist}>.
+
+See more at L<Dist::Zilla::Plugin::GithubMeta>.
+
+=head2 GithubMeta.remote
+
+Remote names to inspect for github repository. Default values are C<origin>, C<github>, C<gh>. You can
+provide multiple remote names
+
+    [@Author::CHIM]
+    GithubMeta.remote = foo
+    GithubMeta.remote = bar
+
+See more at L<Dist::Zilla::Plugin::GithubMeta>.
+
+=head2 GithubMeta.issues
+
+Inserts a bugtracker url to metadata. Default value is C<1>.
+
+See more at L<Dist::Zilla::Plugin::GithubMeta>.
+
 =head1 METHODS
 
 =head2 configure
 
 Bundle's configuration for role L<Dist::Zilla::Role::PluginBundle::Easy>.
 
+=head1 FAKE RELEASE
+
+Use option C<fake_release> in bundle configuration:
+
+    [@Author::CHIM]
+    ...
+    fake_release = 1
+
+or environment variable C<FAKE>:
+
+    FAKE=1 dzil release
+
+The distribution won't actually uploaded to the CPAN if option or variable will found.
+
 =head1 SEE ALSO
 
 L<Dist::Zilla>
@@ -473,6 +490,10 @@ L<Dist::Zilla::Plugin::GatherDir>
 
 L<Dist::Zilla::Plugin::Git>
 
+L<Dist::Zilla::Plugin::TravisCI::StatusBadge>
+
+L<Dist::Zilla::Plugin::GithubMeta>
+
 =head1 AUTHOR
 
 Anton Gerasimov <chim@cpan.org>
